==> haskell-lsp0-types-0.24.0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lsp-types
version:              0.24.0.0
visibility:           public
id:                   haskell-lsp-types-0.24.0.0-3WSuUMxKhyt1jIWuL6SvYL
key:                  haskell-lsp-types-0.24.0.0-3WSuUMxKhyt1jIWuL6SvYL
license:              MIT
copyright:            Alan Zimmerman, 2016-2020
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/haskell-lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  41e541eb6717e4f8c90d74f3a78f1100
exposed:              True
exposed-modules:
    Language.Haskell.LSP.Types Language.Haskell.LSP.Types.Capabilities
    Language.Haskell.LSP.Types.Constants
    Language.Haskell.LSP.Types.Lens
    Language.Haskell.LSP.Types.MessageFuncs
    Language.Haskell.LSP.Types.Utils

hidden-modules:
    Language.Haskell.LSP.Types.ClientCapabilities
    Language.Haskell.LSP.Types.CodeAction
    Language.Haskell.LSP.Types.Color Language.Haskell.LSP.Types.Command
    Language.Haskell.LSP.Types.Completion
    Language.Haskell.LSP.Types.DataTypesJSON
    Language.Haskell.LSP.Types.Diagnostic
    Language.Haskell.LSP.Types.DocumentFilter
    Language.Haskell.LSP.Types.FoldingRange
    Language.Haskell.LSP.Types.Hover Language.Haskell.LSP.Types.List
    Language.Haskell.LSP.Types.Location
    Language.Haskell.LSP.Types.MarkupContent
    Language.Haskell.LSP.Types.Message
    Language.Haskell.LSP.Types.Progress
    Language.Haskell.LSP.Types.Symbol
    Language.Haskell.LSP.Types.TextDocument
    Language.Haskell.LSP.Types.Uri Language.Haskell.LSP.Types.Window
    Language.Haskell.LSP.Types.WorkspaceEdit
    Language.Haskell.LSP.Types.WorkspaceFolders

import-dirs:          /usr/lib/ghc-8.10.4/site-local/haskell-lsp-types-0.24.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/haskell-lsp-types-0.24.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/haskell-lsp-types-0.24.0.0

hs-libraries:         HShaskell-lsp-types-0.24.0.0-3WSuUMxKhyt1jIWuL6SvYL
depends:
    aeson-1.5.6.0-KKLnIH6l1ju5f1LsAaB2FK base-4.14.1.0 binary-0.8.8.0
    bytestring-0.10.12.0 data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV
    deepseq-1.4.4.0 filepath-1.4.2.1
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    lens-5.0.1-167i7l6rbiSBm4dtFYmwmy
    network-uri-2.6.4.1-92yvtIIV9r4DFCfy93rBAD
    scientific-0.3.6.2-D0hjJkVU90r4jvb4s5pFyS text-1.2.4.1
    unordered-containers-0.2.13.0-Hta4uSSpiP48joPsanuYfX

haddock-interfaces:
    /usr/share/doc/haskell-lsp0-types/html/haskell-lsp-types.haddock

haddock-html:         /usr/share/doc/haskell-lsp0-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp0-types-0.24.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp0-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lsp-types
version:              0.24.0.0
visibility:           public
id:                   haskell-lsp-types-0.24.0.0-FpYe4mT6Tvt5NbS6F6Idhe
key:                  haskell-lsp-types-0.24.0.0-FpYe4mT6Tvt5NbS6F6Idhe
license:              MIT
copyright:            Alan Zimmerman, 2016-2020
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/alanz/haskell-lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  9a955397ff2171e6aebcec882170a23d
exposed:              True
exposed-modules:
    Language.Haskell.LSP.Types Language.Haskell.LSP.Types.Capabilities
    Language.Haskell.LSP.Types.Constants
    Language.Haskell.LSP.Types.Lens
    Language.Haskell.LSP.Types.MessageFuncs
    Language.Haskell.LSP.Types.Utils

hidden-modules:
    Language.Haskell.LSP.Types.ClientCapabilities
    Language.Haskell.LSP.Types.CodeAction
    Language.Haskell.LSP.Types.Color Language.Haskell.LSP.Types.Command
    Language.Haskell.LSP.Types.Completion
    Language.Haskell.LSP.Types.DataTypesJSON
    Language.Haskell.LSP.Types.Diagnostic
    Language.Haskell.LSP.Types.DocumentFilter
    Language.Haskell.LSP.Types.FoldingRange
    Language.Haskell.LSP.Types.Hover Language.Haskell.LSP.Types.List
    Language.Haskell.LSP.Types.Location
    Language.Haskell.LSP.Types.MarkupContent
    Language.Haskell.LSP.Types.Message
    Language.Haskell.LSP.Types.Progress
    Language.Haskell.LSP.Types.Symbol
    Language.Haskell.LSP.Types.TextDocument
    Language.Haskell.LSP.Types.Uri Language.Haskell.LSP.Types.Window
    Language.Haskell.LSP.Types.WorkspaceEdit
    Language.Haskell.LSP.Types.WorkspaceFolders

import-dirs:          /usr/lib/ghc-8.10.4/site-local/haskell-lsp-types-0.24.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/haskell-lsp-types-0.24.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/haskell-lsp-types-0.24.0.0

hs-libraries:         HShaskell-lsp-types-0.24.0.0-FpYe4mT6Tvt5NbS6F6Idhe
depends:
    aeson-1.5.6.0-Er8hVcKeB6UIjaphu3gpm9 base-4.14.1.0 binary-0.8.8.0
    bytestring-0.10.12.0 data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV
    deepseq-1.4.4.0 filepath-1.4.2.1
    hashable-1.3.1.0-4EsGp1K7uOu2cACWuCidz3
    lens-5.0.1-CBT5lWNfoCXBtiUXpjba85
    network-uri-2.6.4.1-7oiLAsSXZ3KCi5cxTymWsf
    scientific-0.3.6.2-ErrVUcpZzeLEYjP4jqSF4S text-1.2.4.1
    unordered-containers-0.2.13.0-4AoMTstniRpGNa4LW5BINH

haddock-interfaces:
    /usr/share/doc/haskell-lsp0-types/html/haskell-lsp-types.haddock

haddock-html:         /usr/share/doc/haskell-lsp0-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
